Circle class

Circle

Constructors

Circle({required double radius, required Point center})
const

Properties

area double
Get area of circle
no setter
center Point
final
hashCode int
The hash code for this object.
no setteroverride
perimeter double
Get perimeter of circle
no setter
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasPoint(dynamic point) bool
Check if a given point is inside of this circle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override