Line class

Constructors

Line(Point a, Point b)
const

Properties

a Point
final
b Point
final
hashCode int
The hash code for this object.
no setteroverride
length double
Length of this line
no setter
midPoint Point
The midpoint of the line
no setter
points List<Point>
Get list of points
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slope double
Get slope of this line
no setter

Methods

distanceFromAPoint(Point point) double
get the distance from a points to this line
getAngleWith(Line other) Rad
Get the angle between this line and another line
getIntersectPoint(Line other) Point?
Get Intersect point of this line and another line
hasPoint(Point point) bool
Check if a point is belong to this line
innerAngleWith(Line other) Rad
Get the inner angle between this line and another line
intersect(Line other) bool
Check if this line and other line intersect
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
outerAngleWith(Line other) Rad
Get the outer angle between this line and another line
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override