Polygon class

Constructors

Polygon(List<Point> vertices)
const

Properties

area double
no setter
bottomPoint Point
Get the furthest bottom point of the polygon
no setter
edges List<Line>
Get all edges of this polygon
no setter
hashCode int
The hash code for this object.
no setterinherited
mostLeftPoint Point
Get the furthest left point of the polygon
no setter
mostRightPoint Point
Get the furthest right point of the polygon
no setter
perimeter double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topPoint Point
Get the furthest top point of the polygon
no setter
vertices List<Point>
List of vertices of polygon
final

Methods

contains(Point point) bool
Check if a point is inside this polygon
getBound() Polygon
Get all the boundary of the polygon
getCircumCentroid() Point
Get the centroid of Outer circle
getCircumCircle(List<Point> list) Circle
Get the outer circle
getClosetVertex(Point point) Point
Get closet vertex to the point
getFurthestVertex(Point point) Point
Get furthest vertex to the point
getInnerCentroid() Point
Get the centroid of inner circle
getInnerCircle() Circle
Get the outer circle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited