Circle class
Circle
Properties
Methods
-
hasPoint(
dynamic point) → bool - Check if a given point is inside of this circle
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override