Point class
Properties
Methods
-
distanceTo(
Point other) → double -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pointAtAngle(
double radius, double angle) → Point - generates a point at a specified angle and distance from a center point
-
pointAtDistance(
double distance, [double angle = 0]) → Point - Get the point at a distance to this point
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator %(
Point other) → double -
operator *(
double scalar) → Point -
operator +(
Point other) → Point -
operator -(
Point other) → Point -
operator /(
double scalar) → Point -
operator ==(
Object other) → bool -
The equality operator.
override