Triangle class
Properties
- a → Point
-
final
- AB → Line
-
Line that goes from a to b;
no setter
- AC → Line
-
Line that goes from a to c;
no setter
-
angles
→ List<
Rad> -
no setter
- area → double
-
no setter
- b → Point
-
final
- baseLine → Line
-
Check if this triangle is right
no setter
- BC → Line
-
Line that goes from b to c;
no setter
- c → Point
-
final
- CA → Line
-
Line that goes from c to a;
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
Get height value of this triangle
no setter
- heightLine → Line
-
Get height Line
no setter
- orthocenter → Point
-
Get orthocenter of this triangle
no setter
- perimeter → double
-
no setter
- posVertex → Point
-
Pos vertex
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sides
→ List<
Line> -
Get 3 sides of this triangle
no setter
-
vertices
→ List<
Point> -
Get list of 3 vertices of this triangle
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited